@@ -1,7 +1,7 @@
 /*
  * ALSA kernel API and common-type definitions
  *
- *  Copyright (c) 2011 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2011-2012 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -656,7 +656,7 @@ typedef struct _snd_timer_tread {
 
 /* control interface */
 
-#define SNDRV_CTL_VERSION		SNDRV_PROTOCOL_VERSION(2, 0, 6)
+#define SNDRV_CTL_VERSION		SNDRV_PROTOCOL_VERSION(2, 0, 7)
 
 typedef struct snd_ctl_card_info {
 	int card;
@@ -731,7 +731,7 @@ typedef struct snd_ctl_elem_list {
 typedef struct snd_ctl_elem_info {
 	snd_ctl_elem_id_t id;
 	int type;
-	unsigned int access;
+	unsigned int _access;
 	unsigned int count;
 	pid_t owner;
 	union {
@@ -749,6 +749,8 @@ typedef struct snd_ctl_elem_info {
 			unsigned int items;
 			unsigned int item;
 			char name[64];
+			unsigned long long names_ptr;
+			unsigned int names_length;
 		} enumerated;
 		unsigned char reserved[128];
 	} value;
