@@ -1,7 +1,7 @@
 /*
  *  SALSA-Lib - Control Interface
  *
- *  Copyright (c) 2007-2011 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2007-2012 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -38,12 +38,19 @@
  * open/close
  */
 
+#if SALSA_CHECK_ABI
+int _snd_ctl_open(snd_ctl_t **ctlp, const char *name, int mode,
+		  unsigned int magic)
+#else
 int snd_ctl_open(snd_ctl_t **ctlp, const char *name, int mode)
+#endif
 {
 	snd_ctl_t *ctl;
 	char filename[sizeof(SALSA_DEVPATH) + 24];
 	int err, fmode, fd, card, ver;
 
+	check_incompatible_abi(magic, SALSA_CTL_MAGIC);
+
 	*ctlp = NULL;
 
 	err = _snd_dev_get_device(name, &card, NULL, NULL);
@@ -97,7 +104,7 @@ int snd_ctl_close(snd_ctl_t *ctl)
 	return 0;
 }
 
-
+#if SALSA_HAS_USER_ELEM_SUPPORT
 /*
  * add/remove user-defined controls
  */
@@ -113,9 +120,9 @@ int snd_ctl_elem_add_integer(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
 	memzero_valgrind(&info, sizeof(info));
 	info.id = *id;
 	info.type = SND_CTL_ELEM_TYPE_INTEGER;
-	info.access = SNDRV_CTL_ELEM_ACCESS_READWRITE;
+	info._access = SNDRV_CTL_ELEM_ACCESS_READWRITE;
 #if SALSA_HAS_TLV_SUPPORT
-	info.access |= SNDRV_CTL_ELEM_ACCESS_TLV_READWRITE;
+	info._access |= SNDRV_CTL_ELEM_ACCESS_TLV_READWRITE;
 #endif
 	info.count = count;
 	info.value.integer.min = min;
@@ -182,6 +189,37 @@ int snd_ctl_elem_add_iec958(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id)
 	return snd_ctl_elem_add(ctl, &info);
 }
 
+int snd_ctl_elem_add_enumerated(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
+				unsigned int count, unsigned int items,
+				const char *const names[])
+{
+	snd_ctl_elem_info_t info;
+	char buf[256];
+	int len;
+
+	if (ctl->protocol < SNDRV_PROTOCOL_VERSION(2, 0, 7))
+		return -ENXIO;
+	if (!items)
+		return -EINVAL;
+
+	memzero_valgrind(&info, sizeof(info));
+	info.id = *id;
+	info.type = SND_CTL_ELEM_TYPE_ENUMERATED;
+	info.count = count;
+	info.value.enumerated.items = items;
+	/* flatten item strings to a temp buffer */
+	for (len = 0; items; items--, names++) {
+		int l = strlen(*names) + 1;
+		if (len + l >= sizeof(buf))
+			return -ENOMEM;
+		memcpy(buf + len, *names, l);
+		len += l;
+	}
+	info.value.enumerated.names_ptr = (uintptr_t)buf;
+	info.value.enumerated.names_length = len;
+	return snd_ctl_elem_add(ctl, &info);
+}
+#endif /* USER_ELEM_SUPPORT */
 
 #if SALSA_HAS_TLV_SUPPORT
 /*
@@ -355,6 +393,48 @@ int snd_async_add_ctl_handler(snd_async_handler_t **handler, snd_ctl_t *ctl,
 /* max size of a TLV entry for dB information (including compound one) */
 #define MAX_TLV_RANGE_SIZE	256
 
+/* parse dB info from the given TLV */
+int snd_tlv_parse_dB_info(unsigned int *tlv,
+			  unsigned int tlv_size,
+			  unsigned int **db_tlvp)
+{
+	unsigned int type;
+	unsigned int size;
+	int err;
+
+	*db_tlvp = NULL;
+	type = tlv[0];
+	size = tlv[1];
+	tlv_size -= 2 * sizeof(int);
+	if (size > tlv_size)
+		return -EINVAL;
+	switch (type) {
+	case SND_CTL_TLVT_CONTAINER:
+		size = int_index(size) * sizeof(int);
+		tlv += 2;
+		while (size > 0) {
+			unsigned int len;
+			err = snd_tlv_parse_dB_info(tlv, size, db_tlvp);
+			if (err != 0)
+				return err;
+			len = int_index(tlv[1]) + 2;
+			size -= len * sizeof(int);
+			tlv += len;
+		}
+		return -EINVAL;
+	case SND_CTL_TLVT_DB_SCALE:
+	case SND_CTL_TLVT_DB_MINMAX:
+	case SND_CTL_TLVT_DB_MINMAX_MUTE:
+#if SALSA_SUPPORT_FLOAT
+	case SND_CTL_TLVT_DB_LINEAR:
+#endif
+	case SND_CTL_TLVT_DB_RANGE:
+		*db_tlvp = tlv;
+		return size + sizeof(int) * 2;
+	}
+	return 0;
+}
+
 /* convert the given raw volume value to a dB gain
  */
 static int tlv_to_dB_range(unsigned int *tlv, long rangemin, long rangemax,
