@@ -28,6 +28,15 @@ struct _snd_ctl {
 };
 
 
+#if SALSA_CHECK_ABI
+#define SALSA_CTL_MAGIC		sizeof(struct _snd_ctl)
+__SALSA_EXPORT_FUNC
+int snd_ctl_open(snd_ctl_t **ctl, const char *name, int mode)
+{
+	return _snd_ctl_open(ctl, name, mode, SALSA_CTL_MAGIC);
+}
+#endif
+
 __SALSA_EXPORT_FUNC
 int snd_ctl_nonblock(snd_ctl_t *ctl, int nonblock)
 {
@@ -103,9 +112,13 @@ int snd_ctl_elem_info(snd_ctl_t *ctl, snd_ctl_elem_info_t *info)
 __SALSA_EXPORT_FUNC
 int snd_ctl_elem_add(snd_ctl_t *ctl, snd_ctl_elem_info_t *info)
 {
+#if SALSA_HAS_USER_ELEM_SUPPORT
 	if (ioctl(ctl->fd, SNDRV_CTL_IOCTL_ELEM_ADD, info) < 0)
 		return -errno;
 	return 0;
+#else
+	return -ENXIO;
+#endif
 }
 
 __SALSA_EXPORT_FUNC
@@ -508,50 +521,50 @@ snd_ctl_elem_type_t snd_ctl_elem_info_get_type(const snd_ctl_elem_info_t *obj)
 __SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_readable(const snd_ctl_elem_info_t *obj)
 {
-	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_READ);
+	return !!(obj->_access & SNDRV_CTL_ELEM_ACCESS_READ);
 }
 
 __SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_writable(const snd_ctl_elem_info_t *obj)
 {
-	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_WRITE);
+	return !!(obj->_access & SNDRV_CTL_ELEM_ACCESS_WRITE);
 }
 
 __SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_volatile(const snd_ctl_elem_info_t *obj)
 {
-	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_VOLATILE);
+	return !!(obj->_access & SNDRV_CTL_ELEM_ACCESS_VOLATILE);
 }
 
 __SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_inactive(const snd_ctl_elem_info_t *obj)
 {
-	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_INACTIVE);
+	return !!(obj->_access & SNDRV_CTL_ELEM_ACCESS_INACTIVE);
 }
 
 __SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_locked(const snd_ctl_elem_info_t *obj)
 {
-	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_LOCK);
+	return !!(obj->_access & SNDRV_CTL_ELEM_ACCESS_LOCK);
 }
 
 __SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_owner(const snd_ctl_elem_info_t *obj)
 {
-	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_OWNER);
+	return !!(obj->_access & SNDRV_CTL_ELEM_ACCESS_OWNER);
 }
 
 __SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_user(const snd_ctl_elem_info_t *obj)
 {
-	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_USER);
+	return !!(obj->_access & SNDRV_CTL_ELEM_ACCESS_USER);
 }
 
 __SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_tlv_readable(const snd_ctl_elem_info_t *obj)
 {
 #if SALSA_HAS_TLV_SUPPORT
-	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_TLV_READ);
+	return !!(obj->_access & SNDRV_CTL_ELEM_ACCESS_TLV_READ);
 #else
 	return 0;
 #endif
@@ -561,7 +574,7 @@ __SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_tlv_writable(const snd_ctl_elem_info_t *obj)
 {
 #if SALSA_HAS_TLV_SUPPORT
-	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_TLV_WRITE);
+	return !!(obj->_access & SNDRV_CTL_ELEM_ACCESS_TLV_WRITE);
 #else
 	return 0;
 #endif
@@ -571,7 +584,7 @@ __SALSA_EXPORT_FUNC
 int snd_ctl_elem_info_is_tlv_commandable(const snd_ctl_elem_info_t *obj)
 {
 #if SALSA_HAS_TLV_SUPPORT
-	return !!(obj->access & SNDRV_CTL_ELEM_ACCESS_TLV_COMMAND);
+	return !!(obj->_access & SNDRV_CTL_ELEM_ACCESS_TLV_COMMAND);
 #else
 	return 0;
 #endif
@@ -1010,6 +1023,46 @@ int snd_ctl_convert_from_dB(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
 }
 #endif /* !SALSA_HAS_TLV_SUPPORT */
 
+/*
+ */
+#if !SALSA_HAS_USER_ELEM_SUPPORT
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
+int snd_ctl_elem_add_integer(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
+			     unsigned int count, long min, long max, long step)
+{
+	return -ENXIO;
+}
+
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
+int snd_ctl_elem_add_integer64(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
+			       unsigned int count, long long min, long long max,
+			       long long step)
+{
+	return -ENXIO;
+}
+
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
+int snd_ctl_elem_add_boolean(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
+			     unsigned int count)
+{
+	return -ENXIO;
+}
+
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
+int snd_ctl_elem_add_iec958(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id)
+{
+	return -ENXIO;
+}
+
+__SALSA_EXPORT_FUNC __SALSA_NOT_IMPLEMENTED
+int snd_ctl_elem_add_enumerated(snd_ctl_t *ctl, const snd_ctl_elem_id_t *id,
+				unsigned int count, unsigned int items,
+				const char *const names[])
+{
+	return -ENXIO;
+}
+#endif /* !SALSA_HAS_USER_ELEM_SUPPORT */
+
 /*
  * not implemented yet
  */
@@ -1076,15 +1129,4 @@ snd_ctl_t *snd_async_handler_get_ctl(snd_async_handler_t *handler)
 
 #endif /* SALSA_HAS_ASYNC_SUPPORT */
 
-#if SALSA_HAS_TLV_SUPPORT
-__SALSA_EXPORT_FUNC
-int snd_tlv_parse_dB_info(unsigned int *tlv, unsigned int tlv_size,
-			  unsigned int **db_tlvp)
-{
-	/* just for simplicity */
-	*db_tlvp = tlv;
-	return 0;
-}
-#endif /* SALSA_HAS_TLV_SUPPORT */
-
 #endif /* __ALSA_CTL_MACROS_H */
