@@ -1,7 +1,7 @@
 /*
  *  SALSA-Lib - PCM Interface
  *
- *  Copyright (c) 2007-2011 by Takashi Iwai <tiwai@suse.de>
+ *  Copyright (c) 2007-2012 by Takashi Iwai <tiwai@suse.de>
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as
@@ -40,45 +40,30 @@ static void snd_pcm_hw_munmap_status(snd_pcm_t *pcm);
  * open/close
  */
 
-/* open the substream with the given subdevice number */
-static int open_with_subdev(const char *filename, int fmode,
-			    int card, int subdev)
+static int get_pcm_subdev(int fd)
 {
 	snd_pcm_info_t info;
-	snd_ctl_t *ctl;
-	int err, fd;
-
-	err = _snd_ctl_hw_open(&ctl, card);
-	if (err < 0)
-		return err;
-
-	err = snd_ctl_pcm_prefer_subdevice(ctl, subdev);
-	if (err < 0)
-		return err;
-
-	fd = open(filename, fmode);
-	if (fd < 0)
-	        return -errno;
-
 	memzero_valgrind(&info, sizeof(info));
-	if (ioctl(fd, SNDRV_PCM_IOCTL_INFO, &info) >= 0 &&
-	    info.subdevice == subdev) {
-		snd_ctl_close(ctl);
-		return fd;
-	}
-	close(fd);
-	snd_ctl_close(ctl);
-	return -EBUSY;
+	if (ioctl(fd, SNDRV_PCM_IOCTL_INFO, &info) < 0)
+		return -1;
+	return info.subdevice;
 }
 
+#if SALSA_CHECK_ABI
+int _snd_pcm_open(snd_pcm_t **pcmp, const char *name, 
+		  snd_pcm_stream_t stream, int mode, unsigned int magic)
+#else
 int snd_pcm_open(snd_pcm_t **pcmp, const char *name, 
 		 snd_pcm_stream_t stream, int mode)
+#endif
 {
 	char filename[sizeof(SALSA_DEVPATH) + 24];
 	int card, dev, subdev;
 	int fd, err, fmode, ver;
 	snd_pcm_t *pcm = NULL;
 
+	check_incompatible_abi(magic, SALSA_PCM_MAGIC);
+
 	*pcmp = NULL;
 
 	err = _snd_dev_get_device(name, &card, &dev, &subdev);
@@ -93,13 +78,23 @@ int snd_pcm_open(snd_pcm_t **pcmp, const char *name,
 		fmode |= O_ASYNC;
 
 	if (subdev >= 0) {
-		fd = open_with_subdev(filename, fmode, card, subdev);
+		fd = _snd_open_subdev(filename, fmode, card, subdev,
+				      SNDRV_CTL_IOCTL_PCM_PREFER_SUBDEVICE);
 		if (fd < 0)
 			return fd;
+		if (get_pcm_subdev(fd) != subdev) {
+			close(fd);
+			return -EBUSY;
+		}
 	} else {
 		fd = open(filename, fmode);
 		if (fd < 0)
 			return -errno;
+		subdev = get_pcm_subdev(fd);
+		if (subdev < 0) {
+			close(fd);
+			return -EBUSY;
+		}
 	}
 	if (!(mode & SND_PCM_NONBLOCK)) {
 		fmode &= ~O_NONBLOCK;
@@ -110,15 +105,6 @@ int snd_pcm_open(snd_pcm_t **pcmp, const char *name,
 		err = -errno;
 		goto error;
 	}
-	if (subdev < 0) {
-		snd_pcm_info_t info;
-		memzero_valgrind(&info, sizeof(info));
-		if (ioctl(fd, SNDRV_PCM_IOCTL_INFO, &info) < 0) {
-			err = -errno;
-			goto error;
-		}
-		subdev = info.subdevice;
-	}
 
 	pcm = calloc(1, sizeof(*pcm));
 	if (!pcm) {
@@ -146,8 +132,7 @@ int snd_pcm_open(snd_pcm_t **pcmp, const char *name,
 
  error:
 	free(pcm);
-	if (fd >= 0)
-		close(fd);
+	close(fd);
 	return err;
 }
 
@@ -472,7 +457,7 @@ int snd_pcm_dump_hw_setup(snd_pcm_t *pcm, snd_output_t *out)
 	snd_output_printf(out, "  stream       : %s\n",
 			  snd_pcm_stream_name(pcm->stream));
 	snd_output_printf(out, "  access       : %s\n",
-			  snd_pcm_access_name(pcm->access));
+			  snd_pcm_access_name(pcm->_access));
 	snd_output_printf(out, "  format       : %s\n",
 			  snd_pcm_format_name(pcm->format));
 	snd_output_printf(out, "  subformat    : %s\n",
@@ -746,12 +731,10 @@ int snd_pcm_areas_copy(const snd_pcm_channel_area_t *dst_areas,
 		       unsigned int channels, snd_pcm_uframes_t frames,
 		       snd_pcm_format_t format)
 {
-	int width;
 	if (!channels)
 		return -EINVAL;
 	if (!frames)
 		return -EINVAL;
-	width = snd_pcm_format_physical_width(format);
 	while (channels > 0) {
 		snd_pcm_area_copy(dst_areas, dst_offset,
 				  src_areas, src_offset,
